==> xoonips-3.46a.zip: xoonips-3.46a/xoonips/class/base/utility.class.php <==
<?php
// $Revision: 1.1.2.4 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
if ( ! defined( 'XOOPS_ROOT_PATH' ) ) {
  exit();
}

/**
 * abstract class for xoonips utility classes
 */
class XooNIpsUtility {

  /**
   * singleton class flag. true if class is singleton 
   * @access private
   * @var bool
   */
  var $_is_singleton = false;

  /**
   * set flag for singleton class
   * @access protected
   */
  function setSingleton() {
    $this->_is_singleton = true;
  }

  /**
   * unset flag for non-singleton class
   * @access protected
   */
  function unsetSingleton() {
    $this->_is_singleton = false;
  }

  /**
   * unset flag for non-singleton class
   * @access public
   * @return bool true if class is singleton
   */
  function isSingleton() {
    return $this->_is_singleton;
  }
}

?>

==> xoonips-3.49.zip: xoonips-3.49/xoonips/class/base/utility.class.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
defined('XOOPS_ROOT_PATH') || exit('XOOPS root path not defined');

/**
 * abstract class for xoonips utility classes.
 */
class XooNIpsUtility
{
    /**
     * singleton class flag. true if class is singleton.
     *
     * @var bool
     */
    public $_is_singleton = false;

    /**
     * set flag for singleton class.
     */
    public function setSingleton()
    {
        $this->_is_singleton = true;
    }

    /**
     * unset flag for non-singleton class.
     */
    public function unsetSingleton()
    {
        $this->_is_singleton = false;
    }

    /**
     * unset flag for non-singleton class.
     *
     * @return bool true if class is singleton
     */
    public function isSingleton()
    {
        return $this->_is_singleton;
    }
}
